
from setuptools import setup

setup(
 name='pyrandomcolor',
 version='1.0',
 long_description='Add random color to your turtle computer graphics.',
 url='https://github.com/purcellconsult/PyRandomColor',
 author='Doug Purcell',
 author_email='purcellconsult@gmail.com',
 license = 'GPL3.0',
 classifiers= [

    'Development Status :: 4 - Beta',

    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.6',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.2',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4',
],

keywords = 'turtle module,  random color, color, computer graphics, computer art'
)
